From 8fe334e26b2980ffaffce679c27e3294d8f2eb23 Mon Sep 17 00:00:00 2001
From: Peter Pentchev <roam@ringlet.net>
Date: Wed, 9 Mar 2011 17:42:48 +0200
Subject: [PATCH 10/15] Get CFLAGS, CPPFLAGS and LDFLAGS from dpkg-buildflags.

---
 debian/changelog               |    3 +++
 debian/control                 |    3 ++-
 debian/patches/unix-port.patch |    6 +++---
 debian/rules                   |   11 ++++++++---
 4 files changed, 16 insertions(+), 7 deletions(-)

diff --git a/debian/changelog b/debian/changelog
index 6a5b7db..4e5a53c 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -10,12 +10,15 @@ alex4 (1.1-4) UNRELEASED; urgency=low
       Closes: #617465
     - put the aldumb library before the Allegro libraries that it
       depends on
+    - honor CPPFLAGS, CFLAGS and LDFLAGS
   * Convert to the 3.0 (quilt) source format.
   * Add misc:Depends to the alex4-data package just in case.
   * Expand the alex4-data package's long description.
   * Bump the debhelper compatibility level to 8 and minimize the rules file
     using debhelper override targets.
   * Bump Standards-Version to 3.9.1 with no changes.
+  * Use dpkg-buildflags to obtain the default values for CPPFLAGS, CFLAGS
+    and LDFLAGS.
 
  -- Peter Pentchev <roam@ringlet.net>  Wed, 09 Mar 2011 14:14:04 +0200
 
diff --git a/debian/control b/debian/control
index 11c0763..8663758 100644
--- a/debian/control
+++ b/debian/control
@@ -3,7 +3,8 @@ Section: games
 Priority: optional
 Maintainer: Debian Games Team <pkg-games-devel@lists.alioth.debian.org>
 Uploaders: Peter De Wachter <pdewacht@gmail.com>
-Build-Depends: debhelper (>= 8), liballegro4.2-dev (>= 2:4.2.2-2), libdumb1-dev, libaldmb1-dev
+Build-Depends: debhelper (>= 8), dpkg-dev (>= 1.15.7~),
+	liballegro4.2-dev (>= 2:4.2.2-2), libdumb1-dev, libaldmb1-dev
 Standards-Version: 3.9.1
 Homepage: http://allegator.sourceforge.net/
 Vcs-Svn: svn://svn.debian.org/svn/pkg-games/packages/trunk/alex4/
diff --git a/debian/patches/unix-port.patch b/debian/patches/unix-port.patch
index d557c70..3346709 100644
--- a/debian/patches/unix-port.patch
+++ b/debian/patches/unix-port.patch
@@ -451,7 +451,7 @@ Based on Hans de Goede's patch for Fedora.
 @@ -0,0 +1,24 @@
 +PREFIX  = /usr/local
 +DATADIR = $(PREFIX)/share/$(TARGET)
-+CFLAGS  = -g -Wall -Wno-deprecated-declarations -O2
++CFLAGS  ?= -g -Wall -Wno-deprecated-declarations -O2
 +LIBS = -laldmb -ldumb `allegro-config --libs`
 +DEFINES = -DDATADIR=\"$(DATADIR)/\"
 +OBJS    =  actor.o    edit.o  map.o       player.o    shooter.o unix.o \
@@ -460,10 +460,10 @@ Based on Hans de Goede's patch for Fedora.
 +TARGET  = alex4
 +
 +$(TARGET): $(OBJS)
-+	$(CC) -o $@ $^ $(LIBS)
++	$(CC) $(LDFLAGS) -o $@ $^ $(LIBS)
 +
 +%.o: %.c
-+	$(CC) $(CFLAGS) $(DEFINES) -o $@ -c $<
++	$(CC) $(CPPFLAGS) $(CFLAGS) $(DEFINES) -o $@ -c $<
 +
 +install: $(TARGET)
 +	mkdir -p $(PREFIX)/bin
diff --git a/debian/rules b/debian/rules
index 36e0e66..d0c6a28 100755
--- a/debian/rules
+++ b/debian/rules
@@ -3,11 +3,16 @@
 # Uncomment this to turn on verbose mode.
 #export DH_VERBOSE=1
 
-CFLAGS = -Wall -g $(if $(findstring noopt,$(DEB_BUILD_OPTIONS)), -O0, -O2)
+CFLAGS:=	$(shell dpkg-buildflags --get CFLAGS)
+CPPFLAGS:=	$(shell dpkg-buildflags --get CPPFLAGS)
+LDFLAGS:=	$(shell dpkg-buildflags --get LDFLAGS)
+
+CFLAGS+=	-Wall
+
+export CPPFLAGS CFLAGS LDFLAGS
 
 override_dh_auto_build:
-	dh_auto_build -D src -- CFLAGS="$(CFLAGS)" \
-		DATADIR=/usr/share/games/alex4
+	dh_auto_build -D src -- DATADIR=/usr/share/games/alex4
 
 override_dh_auto_clean:
 	dh_auto_clean -D src
-- 
1.7.2.3

